16.14. cdist-type__check_messages(7) — cdist 4.11.0 documentation

# 16.14. cdist-type__check_messages(7)

## 16.14.1. NAME

cdist-type__check_messages - Check messages for pattern and execute command on match.

## 16.14.2. DESCRIPTION

Check messages for pattern and execute command on match.

This type is useful if you chain together multiple related types using dependencies and want to restart service if at least one type changes something.

For more information about messages see cdist messaging.

For more information about dependencies and execution order see cdist manifest documentation.

## 16.14.3. REQUIRED PARAMETERS

pattern
  Extended regular expression pattern for search (passed to `grep -E`).
execute
  Command to execute on pattern match.

## 16.14.4. EXAMPLES

    __check_messages munin \
        --pattern '^__(file|link|line)/etc/munin/' \
        --execute 'service munin-node restart'

## 16.14.5. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.14.6. COPYING

Copyright (C) 2019 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.